@@ -46,7 +46,7 @@ class EmbedProxy:
         return len(self.__dict__)
 
     def __repr__(self) -> str:
-        inner = ', '.join((f'{k}={v!r}' for k, v in self.__dict__.items() if not k.startswith('_')))
+        inner = ', '.join((f'{k}={getattr(self, k)!r}' for k in dir(self) if not k.startswith('_')))
         return f'EmbedProxy({inner})'
 
     def __getattr__(self, attr: str) -> None:
@@ -56,6 +56,16 @@ class EmbedProxy:
         return isinstance(other, EmbedProxy) and self.__dict__ == other.__dict__
 
 
+class EmbedMediaProxy(EmbedProxy):
+    def __init__(self, layer: Dict[str, Any]):
+        super().__init__(layer)
+        self._flags = self.__dict__.pop('flags', 0)
+
+    @property
+    def flags(self) -> AttachmentFlags:
+        return AttachmentFlags._from_value(self._flags or 0)
+
+
 if TYPE_CHECKING:
     from typing_extensions import Self
 
@@ -77,12 +87,7 @@ if TYPE_CHECKING:
         proxy_url: Optional[str]
         height: Optional[int]
         width: Optional[int]
-        flags: Optional[AttachmentFlags]
-
-    class _EmbedVideoProxy(Protocol):
-        url: Optional[str]
-        height: Optional[int]
-        width: Optional[int]
+        flags: AttachmentFlags
 
     class _EmbedProviderProxy(Protocol):
         name: Optional[str]
@@ -148,10 +153,6 @@ class Embed:
     colour: Optional[Union[:class:`Colour`, :class:`int`]]
         The colour code of the embed. Aliased to ``color`` as well.
         This can be set during initialisation.
-    flags: Optional[:class:`EmbedFlags`]
-        The flags of this embed.
-
-        .. versionadded:: 2.5
     """
 
     __slots__ = (
@@ -168,7 +169,7 @@ class Embed:
         '_author',
         '_fields',
         'description',
-        'flags',
+        '_flags',
     )
 
     def __init__(
@@ -188,7 +189,7 @@ class Embed:
         self.type: EmbedType = type
         self.url: Optional[str] = url
         self.description: Optional[str] = description
-        self.flags: Optional[EmbedFlags] = None
+        self._flags: int = 0
 
         if self.title is not None:
             self.title = str(self.title)
@@ -223,6 +224,7 @@ class Embed:
         self.type = data.get('type', None)
         self.description = data.get('description', None)
         self.url = data.get('url', None)
+        self._flags = data.get('flags', 0)
 
         if self.title is not None:
             self.title = str(self.title)
@@ -253,11 +255,6 @@ class Embed:
             else:
                 setattr(self, '_' + attr, value)
 
-        try:
-            self.flags = EmbedFlags._from_value(data['flags'])
-        except KeyError:
-            pass
-
         return self
 
     def copy(self) -> Self:
@@ -318,8 +315,17 @@ class Embed:
             and self.image == other.image
             and self.provider == other.provider
             and self.video == other.video
+            and self._flags == other._flags
         )
 
+    @property
+    def flags(self) -> EmbedFlags:
+        """:class:`EmbedFlags`: The flags of this embed.
+
+        .. versionadded:: 2.5
+        """
+        return EmbedFlags._from_value(self._flags or 0)
+
     @property
     def colour(self) -> Optional[Colour]:
         return getattr(self, '_colour', None)
@@ -408,19 +414,16 @@ class Embed:
 
         Possible attributes you can access are:
 
-        - ``url``
-        - ``proxy_url``
-        - ``width``
-        - ``height``
-        - ``flags``
+        - ``url`` for the image URL.
+        - ``proxy_url`` for the proxied image URL.
+        - ``width`` for the image width.
+        - ``height`` for the image height.
+        - ``flags`` for the image's attachment flags.
 
         If the attribute has no value then ``None`` is returned.
         """
         # Lying to the type checker for better developer UX.
-        data = getattr(self, '_image', {})
-        if 'flags' in data:
-            data['flags'] = AttachmentFlags._from_value(data['flags'])
-        return EmbedProxy(data)  # type: ignore
+        return EmbedMediaProxy(getattr(self, '_image', {}))  # type: ignore
 
     def set_image(self, *, url: Optional[Any]) -> Self:
         """Sets the image for the embed content.
@@ -454,15 +457,16 @@ class Embed:
 
         Possible attributes you can access are:
 
-        - ``url``
-        - ``proxy_url``
-        - ``width``
-        - ``height``
+        - ``url`` for the thumbnail URL.
+        - ``proxy_url`` for the proxied thumbnail URL.
+        - ``width`` for the thumbnail width.
+        - ``height`` for the thumbnail height.
+        - ``flags`` for the thumbnail's attachment flags.
 
         If the attribute has no value then ``None`` is returned.
         """
         # Lying to the type checker for better developer UX.
-        return EmbedProxy(getattr(self, '_thumbnail', {}))  # type: ignore
+        return EmbedMediaProxy(getattr(self, '_thumbnail', {}))  # type: ignore
 
     def set_thumbnail(self, *, url: Optional[Any]) -> Self:
         """Sets the thumbnail for the embed content.
@@ -491,19 +495,21 @@ class Embed:
         return self
 
     @property
-    def video(self) -> _EmbedVideoProxy:
+    def video(self) -> _EmbedMediaProxy:
         """Returns an ``EmbedProxy`` denoting the video contents.
 
         Possible attributes include:
 
         - ``url`` for the video URL.
+        - ``proxy_url`` for the proxied video URL.
         - ``height`` for the video height.
         - ``width`` for the video width.
+        - ``flags`` for the video's attachment flags.
 
         If the attribute has no value then ``None`` is returned.
         """
         # Lying to the type checker for better developer UX.
-        return EmbedProxy(getattr(self, '_video', {}))  # type: ignore
+        return EmbedMediaProxy(getattr(self, '_video', {}))  # type: ignore
 
     @property
     def provider(self) -> _EmbedProviderProxy:
