@@ -42,6 +42,7 @@ __all__ = (
     'ActivityType',
     'NotificationLevel',
     'TeamMembershipState',
+    'TeamMemberRole',
     'WebhookType',
     'ExpireBehaviour',
     'ExpireBehavior',
@@ -68,23 +69,28 @@ __all__ = (
     'AutoModRuleActionType',
     'ForumLayoutType',
     'ForumOrderType',
+    'SelectDefaultValueType',
+    'SKUType',
+    'EntitlementType',
+    'EntitlementOwnerType',
+    'PollLayoutType',
+    'VoiceChannelEffectAnimationType',
+    'SubscriptionStatus',
+    'MessageReferenceType',
 )
 
-if TYPE_CHECKING:
-    from typing_extensions import Self
-
 
 def _create_value_cls(name: str, comparable: bool):
     # All the type ignores here are due to the type checker being unable to recognise
     # Runtime type creation without exploding.
     cls = namedtuple('_EnumValue_' + name, 'name value')
-    cls.__repr__ = lambda self: f'<{name}.{self.name}: {self.value!r}>'  # type: ignore
-    cls.__str__ = lambda self: f'{name}.{self.name}'  # type: ignore
+    cls.__repr__ = lambda self: f'<{name}.{self.name}: {self.value!r}>'
+    cls.__str__ = lambda self: f'{name}.{self.name}'
     if comparable:
-        cls.__le__ = lambda self, other: isinstance(other, self.__class__) and self.value <= other.value  # type: ignore
-        cls.__ge__ = lambda self, other: isinstance(other, self.__class__) and self.value >= other.value  # type: ignore
-        cls.__lt__ = lambda self, other: isinstance(other, self.__class__) and self.value < other.value  # type: ignore
-        cls.__gt__ = lambda self, other: isinstance(other, self.__class__) and self.value > other.value  # type: ignore
+        cls.__le__ = lambda self, other: isinstance(other, self.__class__) and self.value <= other.value
+        cls.__ge__ = lambda self, other: isinstance(other, self.__class__) and self.value >= other.value
+        cls.__lt__ = lambda self, other: isinstance(other, self.__class__) and self.value < other.value
+        cls.__gt__ = lambda self, other: isinstance(other, self.__class__) and self.value > other.value
     return cls
 
 
@@ -99,7 +105,14 @@ class EnumMeta(type):
         _enum_member_map_: ClassVar[Dict[str, Any]]
         _enum_value_map_: ClassVar[Dict[Any, Any]]
 
-    def __new__(cls, name: str, bases: Tuple[type, ...], attrs: Dict[str, Any], *, comparable: bool = False) -> Self:
+    def __new__(
+        cls,
+        name: str,
+        bases: Tuple[type, ...],
+        attrs: Dict[str, Any],
+        *,
+        comparable: bool = False,
+    ) -> EnumMeta:
         value_mapping = {}
         member_mapping = {}
         member_names = []
@@ -202,11 +215,18 @@ class ChannelType(Enum):
     private_thread = 12
     stage_voice = 13
     forum = 15
+    media = 16
 
     def __str__(self) -> str:
         return self.name
 
 
+class MessageReferenceType(Enum):
+    default = 0
+    reply = 0
+    forward = 1
+
+
 class MessageType(Enum):
     default = 0
     recipient_add = 1
@@ -241,6 +261,12 @@ class MessageType(Enum):
     stage_raise_hand = 30
     stage_topic = 31
     guild_application_premium_subscription = 32
+    guild_incident_alert_mode_enabled = 36
+    guild_incident_alert_mode_disabled = 37
+    guild_incident_report_raid = 38
+    guild_incident_report_false_alarm = 39
+    purchase_notification = 44
+    poll_result = 46
 
 
 class SpeakingState(Enum):
@@ -314,120 +340,130 @@ class AuditLogActionCategory(Enum):
 
 class AuditLogAction(Enum):
     # fmt: off
-    guild_update                  = 1
-    channel_create                = 10
-    channel_update                = 11
-    channel_delete                = 12
-    overwrite_create              = 13
-    overwrite_update              = 14
-    overwrite_delete              = 15
-    kick                          = 20
-    member_prune                  = 21
-    ban                           = 22
-    unban                         = 23
-    member_update                 = 24
-    member_role_update            = 25
-    member_move                   = 26
-    member_disconnect             = 27
-    bot_add                       = 28
-    role_create                   = 30
-    role_update                   = 31
-    role_delete                   = 32
-    invite_create                 = 40
-    invite_update                 = 41
-    invite_delete                 = 42
-    webhook_create                = 50
-    webhook_update                = 51
-    webhook_delete                = 52
-    emoji_create                  = 60
-    emoji_update                  = 61
-    emoji_delete                  = 62
-    message_delete                = 72
-    message_bulk_delete           = 73
-    message_pin                   = 74
-    message_unpin                 = 75
-    integration_create            = 80
-    integration_update            = 81
-    integration_delete            = 82
-    stage_instance_create         = 83
-    stage_instance_update         = 84
-    stage_instance_delete         = 85
-    sticker_create                = 90
-    sticker_update                = 91
-    sticker_delete                = 92
-    scheduled_event_create        = 100
-    scheduled_event_update        = 101
-    scheduled_event_delete        = 102
-    thread_create                 = 110
-    thread_update                 = 111
-    thread_delete                 = 112
-    app_command_permission_update = 121
-    automod_rule_create           = 140
-    automod_rule_update           = 141
-    automod_rule_delete           = 142
-    automod_block_message         = 143
-    automod_flag_message          = 144
-    automod_timeout_member        = 145
+    guild_update                                      = 1
+    channel_create                                    = 10
+    channel_update                                    = 11
+    channel_delete                                    = 12
+    overwrite_create                                  = 13
+    overwrite_update                                  = 14
+    overwrite_delete                                  = 15
+    kick                                              = 20
+    member_prune                                      = 21
+    ban                                               = 22
+    unban                                             = 23
+    member_update                                     = 24
+    member_role_update                                = 25
+    member_move                                       = 26
+    member_disconnect                                 = 27
+    bot_add                                           = 28
+    role_create                                       = 30
+    role_update                                       = 31
+    role_delete                                       = 32
+    invite_create                                     = 40
+    invite_update                                     = 41
+    invite_delete                                     = 42
+    webhook_create                                    = 50
+    webhook_update                                    = 51
+    webhook_delete                                    = 52
+    emoji_create                                      = 60
+    emoji_update                                      = 61
+    emoji_delete                                      = 62
+    message_delete                                    = 72
+    message_bulk_delete                               = 73
+    message_pin                                       = 74
+    message_unpin                                     = 75
+    integration_create                                = 80
+    integration_update                                = 81
+    integration_delete                                = 82
+    stage_instance_create                             = 83
+    stage_instance_update                             = 84
+    stage_instance_delete                             = 85
+    sticker_create                                    = 90
+    sticker_update                                    = 91
+    sticker_delete                                    = 92
+    scheduled_event_create                            = 100
+    scheduled_event_update                            = 101
+    scheduled_event_delete                            = 102
+    thread_create                                     = 110
+    thread_update                                     = 111
+    thread_delete                                     = 112
+    app_command_permission_update                     = 121
+    soundboard_sound_create                           = 130
+    soundboard_sound_update                           = 131
+    soundboard_sound_delete                           = 132
+    automod_rule_create                               = 140
+    automod_rule_update                               = 141
+    automod_rule_delete                               = 142
+    automod_block_message                             = 143
+    automod_flag_message                              = 144
+    automod_timeout_member                            = 145
+    creator_monetization_request_created              = 150
+    creator_monetization_terms_accepted               = 151
     # fmt: on
 
     @property
     def category(self) -> Optional[AuditLogActionCategory]:
         # fmt: off
         lookup: Dict[AuditLogAction, Optional[AuditLogActionCategory]] = {
-            AuditLogAction.guild_update:                  AuditLogActionCategory.update,
-            AuditLogAction.channel_create:                AuditLogActionCategory.create,
-            AuditLogAction.channel_update:                AuditLogActionCategory.update,
-            AuditLogAction.channel_delete:                AuditLogActionCategory.delete,
-            AuditLogAction.overwrite_create:              AuditLogActionCategory.create,
-            AuditLogAction.overwrite_update:              AuditLogActionCategory.update,
-            AuditLogAction.overwrite_delete:              AuditLogActionCategory.delete,
-            AuditLogAction.kick:                          None,
-            AuditLogAction.member_prune:                  None,
-            AuditLogAction.ban:                           None,
-            AuditLogAction.unban:                         None,
-            AuditLogAction.member_update:                 AuditLogActionCategory.update,
-            AuditLogAction.member_role_update:            AuditLogActionCategory.update,
-            AuditLogAction.member_move:                   None,
-            AuditLogAction.member_disconnect:             None,
-            AuditLogAction.bot_add:                       None,
-            AuditLogAction.role_create:                   AuditLogActionCategory.create,
-            AuditLogAction.role_update:                   AuditLogActionCategory.update,
-            AuditLogAction.role_delete:                   AuditLogActionCategory.delete,
-            AuditLogAction.invite_create:                 AuditLogActionCategory.create,
-            AuditLogAction.invite_update:                 AuditLogActionCategory.update,
-            AuditLogAction.invite_delete:                 AuditLogActionCategory.delete,
-            AuditLogAction.webhook_create:                AuditLogActionCategory.create,
-            AuditLogAction.webhook_update:                AuditLogActionCategory.update,
-            AuditLogAction.webhook_delete:                AuditLogActionCategory.delete,
-            AuditLogAction.emoji_create:                  AuditLogActionCategory.create,
-            AuditLogAction.emoji_update:                  AuditLogActionCategory.update,
-            AuditLogAction.emoji_delete:                  AuditLogActionCategory.delete,
-            AuditLogAction.message_delete:                AuditLogActionCategory.delete,
-            AuditLogAction.message_bulk_delete:           AuditLogActionCategory.delete,
-            AuditLogAction.message_pin:                   None,
-            AuditLogAction.message_unpin:                 None,
-            AuditLogAction.integration_create:            AuditLogActionCategory.create,
-            AuditLogAction.integration_update:            AuditLogActionCategory.update,
-            AuditLogAction.integration_delete:            AuditLogActionCategory.delete,
-            AuditLogAction.stage_instance_create:         AuditLogActionCategory.create,
-            AuditLogAction.stage_instance_update:         AuditLogActionCategory.update,
-            AuditLogAction.stage_instance_delete:         AuditLogActionCategory.delete,
-            AuditLogAction.sticker_create:                AuditLogActionCategory.create,
-            AuditLogAction.sticker_update:                AuditLogActionCategory.update,
-            AuditLogAction.sticker_delete:                AuditLogActionCategory.delete,
-            AuditLogAction.scheduled_event_create:        AuditLogActionCategory.create,
-            AuditLogAction.scheduled_event_update:        AuditLogActionCategory.update,
-            AuditLogAction.scheduled_event_delete:        AuditLogActionCategory.delete,
-            AuditLogAction.thread_create:                 AuditLogActionCategory.create,
-            AuditLogAction.thread_delete:                 AuditLogActionCategory.delete,
-            AuditLogAction.thread_update:                 AuditLogActionCategory.update,
-            AuditLogAction.app_command_permission_update: AuditLogActionCategory.update,
-            AuditLogAction.automod_rule_create:           AuditLogActionCategory.create,
-            AuditLogAction.automod_rule_update:           AuditLogActionCategory.update,
-            AuditLogAction.automod_rule_delete:           AuditLogActionCategory.delete,
-            AuditLogAction.automod_block_message:         None,
-            AuditLogAction.automod_flag_message:          None,
-            AuditLogAction.automod_timeout_member:        None,
+            AuditLogAction.guild_update:                             AuditLogActionCategory.update,
+            AuditLogAction.channel_create:                           AuditLogActionCategory.create,
+            AuditLogAction.channel_update:                           AuditLogActionCategory.update,
+            AuditLogAction.channel_delete:                           AuditLogActionCategory.delete,
+            AuditLogAction.overwrite_create:                         AuditLogActionCategory.create,
+            AuditLogAction.overwrite_update:                         AuditLogActionCategory.update,
+            AuditLogAction.overwrite_delete:                         AuditLogActionCategory.delete,
+            AuditLogAction.kick:                                     None,
+            AuditLogAction.member_prune:                             None,
+            AuditLogAction.ban:                                      None,
+            AuditLogAction.unban:                                    None,
+            AuditLogAction.member_update:                            AuditLogActionCategory.update,
+            AuditLogAction.member_role_update:                       AuditLogActionCategory.update,
+            AuditLogAction.member_move:                              None,
+            AuditLogAction.member_disconnect:                        None,
+            AuditLogAction.bot_add:                                  None,
+            AuditLogAction.role_create:                              AuditLogActionCategory.create,
+            AuditLogAction.role_update:                              AuditLogActionCategory.update,
+            AuditLogAction.role_delete:                              AuditLogActionCategory.delete,
+            AuditLogAction.invite_create:                            AuditLogActionCategory.create,
+            AuditLogAction.invite_update:                            AuditLogActionCategory.update,
+            AuditLogAction.invite_delete:                            AuditLogActionCategory.delete,
+            AuditLogAction.webhook_create:                           AuditLogActionCategory.create,
+            AuditLogAction.webhook_update:                           AuditLogActionCategory.update,
+            AuditLogAction.webhook_delete:                           AuditLogActionCategory.delete,
+            AuditLogAction.emoji_create:                             AuditLogActionCategory.create,
+            AuditLogAction.emoji_update:                             AuditLogActionCategory.update,
+            AuditLogAction.emoji_delete:                             AuditLogActionCategory.delete,
+            AuditLogAction.message_delete:                           AuditLogActionCategory.delete,
+            AuditLogAction.message_bulk_delete:                      AuditLogActionCategory.delete,
+            AuditLogAction.message_pin:                              None,
+            AuditLogAction.message_unpin:                            None,
+            AuditLogAction.integration_create:                       AuditLogActionCategory.create,
+            AuditLogAction.integration_update:                       AuditLogActionCategory.update,
+            AuditLogAction.integration_delete:                       AuditLogActionCategory.delete,
+            AuditLogAction.stage_instance_create:                    AuditLogActionCategory.create,
+            AuditLogAction.stage_instance_update:                    AuditLogActionCategory.update,
+            AuditLogAction.stage_instance_delete:                    AuditLogActionCategory.delete,
+            AuditLogAction.sticker_create:                           AuditLogActionCategory.create,
+            AuditLogAction.sticker_update:                           AuditLogActionCategory.update,
+            AuditLogAction.sticker_delete:                           AuditLogActionCategory.delete,
+            AuditLogAction.scheduled_event_create:                   AuditLogActionCategory.create,
+            AuditLogAction.scheduled_event_update:                   AuditLogActionCategory.update,
+            AuditLogAction.scheduled_event_delete:                   AuditLogActionCategory.delete,
+            AuditLogAction.thread_create:                            AuditLogActionCategory.create,
+            AuditLogAction.thread_delete:                            AuditLogActionCategory.delete,
+            AuditLogAction.thread_update:                            AuditLogActionCategory.update,
+            AuditLogAction.app_command_permission_update:            AuditLogActionCategory.update,
+            AuditLogAction.automod_rule_create:                      AuditLogActionCategory.create,
+            AuditLogAction.automod_rule_update:                      AuditLogActionCategory.update,
+            AuditLogAction.automod_rule_delete:                      AuditLogActionCategory.delete,
+            AuditLogAction.automod_block_message:                    None,
+            AuditLogAction.automod_flag_message:                     None,
+            AuditLogAction.automod_timeout_member:                   None,
+            AuditLogAction.creator_monetization_request_created:     None,
+            AuditLogAction.creator_monetization_terms_accepted:      None,
+            AuditLogAction.soundboard_sound_create:                  AuditLogActionCategory.create,
+            AuditLogAction.soundboard_sound_update:                  AuditLogActionCategory.update,
+            AuditLogAction.soundboard_sound_delete:                  AuditLogActionCategory.delete,
         }
         # fmt: on
         return lookup[self]
@@ -467,10 +503,12 @@ class AuditLogAction(Enum):
             return 'thread'
         elif v < 122:
             return 'integration_or_app_command'
-        elif v < 143:
+        elif 139 < v < 143:
             return 'auto_moderation'
         elif v < 146:
             return 'user'
+        elif v < 152:
+            return 'creator_monetization'
 
 
 class UserFlags(Enum):
@@ -514,6 +552,12 @@ class TeamMembershipState(Enum):
     accepted = 2
 
 
+class TeamMemberRole(Enum):
+    admin = 'admin'
+    developer = 'developer'
+    read_only = 'read_only'
+
+
 class WebhookType(Enum):
     incoming = 1
     channel_follower = 2
@@ -576,6 +620,7 @@ class InteractionResponseType(Enum):
     message_update = 7  # for components
     autocomplete_result = 8
     modal = 9  # for modals
+    # premium_required = 10 (deprecated)
 
 
 class VideoQualityMode(Enum):
@@ -607,6 +652,7 @@ class ButtonStyle(Enum):
     success = 3
     danger = 4
     link = 5
+    premium = 6
 
     # Aliases
     blurple = 1
@@ -667,6 +713,7 @@ class Locale(Enum):
     italian = 'it'
     japanese = 'ja'
     korean = 'ko'
+    latin_american_spanish = 'es-419'
     lithuanian = 'lt'
     norwegian = 'no'
     polish = 'pl'
@@ -735,16 +782,19 @@ class AutoModRuleTriggerType(Enum):
     spam = 3
     keyword_preset = 4
     mention_spam = 5
+    member_profile = 6
 
 
 class AutoModRuleEventType(Enum):
     message_send = 1
+    member_update = 2
 
 
 class AutoModRuleActionType(Enum):
     block_message = 1
     send_alert_message = 2
     timeout = 3
+    block_member_interactions = 4
 
 
 class ForumLayoutType(Enum):
@@ -758,6 +808,61 @@ class ForumOrderType(Enum):
     creation_date = 1
 
 
+class SelectDefaultValueType(Enum):
+    user = 'user'
+    role = 'role'
+    channel = 'channel'
+
+
+class SKUType(Enum):
+    durable = 2
+    consumable = 3
+    subscription = 5
+    subscription_group = 6
+
+
+class EntitlementType(Enum):
+    purchase = 1
+    premium_subscription = 2
+    developer_gift = 3
+    test_mode_purchase = 4
+    free_purchase = 5
+    user_gift = 6
+    premium_purchase = 7
+    application_subscription = 8
+
+
+class EntitlementOwnerType(Enum):
+    guild = 1
+    user = 2
+
+
+class PollLayoutType(Enum):
+    default = 1
+
+
+class InviteType(Enum):
+    guild = 0
+    group_dm = 1
+    friend = 2
+
+
+class ReactionType(Enum):
+    normal = 0
+    burst = 1
+
+
+class VoiceChannelEffectAnimationType(Enum):
+    premium = 0
+    basic = 1
+
+
+class SubscriptionStatus(Enum):
+    active = 0
+    ending = 1
+    inactive = 2
+
+
 def create_unknown_value(cls: Type[E], val: Any) -> E:
     value_cls = cls._enum_value_cls_  # type: ignore # This is narrowed below
     name = f'unknown_{val}'
