@@ -166,14 +166,21 @@ class BotBase(GroupMixin[None]):
         help_command: Optional[HelpCommand] = _default,
         tree_cls: Type[app_commands.CommandTree[Any]] = app_commands.CommandTree,
         description: Optional[str] = None,
+        allowed_contexts: app_commands.AppCommandContext = MISSING,
+        allowed_installs: app_commands.AppInstallationType = MISSING,
         intents: discord.Intents,
         **options: Any,
     ) -> None:
         super().__init__(intents=intents, **options)
-        self.command_prefix: PrefixType[BotT] = command_prefix
+        self.command_prefix: PrefixType[BotT] = command_prefix  # type: ignore
         self.extra_events: Dict[str, List[CoroFunc]] = {}
         # Self doesn't have the ClientT bound, but since this is a mixin it technically does
         self.__tree: app_commands.CommandTree[Self] = tree_cls(self)  # type: ignore
+        if allowed_contexts is not MISSING:
+            self.__tree.allowed_contexts = allowed_contexts
+        if allowed_installs is not MISSING:
+            self.__tree.allowed_installs = allowed_installs
+
         self.__cogs: Dict[str, Cog] = {}
         self.__extensions: Dict[str, types.ModuleType] = {}
         self._checks: List[UserCheck] = []
@@ -480,7 +487,7 @@ class BotBase(GroupMixin[None]):
         if len(data) == 0:
             return True
 
-        return await discord.utils.async_all(f(ctx) for f in data)
+        return await discord.utils.async_all(f(ctx) for f in data)  # type: ignore
 
     async def is_owner(self, user: User, /) -> bool:
         """|coro|
@@ -499,6 +506,12 @@ class BotBase(GroupMixin[None]):
 
             ``user`` parameter is now positional-only.
 
+        .. versionchanged:: 2.4
+
+            This function now respects the team member roles if the bot is team-owned.
+            In order to be considered an owner, they must be either an admin or
+            a developer.
+
         Parameters
         -----------
         user: :class:`.abc.User`
@@ -515,10 +528,13 @@ class BotBase(GroupMixin[None]):
         elif self.owner_ids:
             return user.id in self.owner_ids
         else:
-
-            app = await self.application_info()  # type: ignore
+            app: discord.AppInfo = await self.application_info()  # type: ignore
             if app.team:
-                self.owner_ids = ids = {m.id for m in app.team.members}
+                self.owner_ids = ids = {
+                    m.id
+                    for m in app.team.members
+                    if m.role in (discord.TeamMemberRole.admin, discord.TeamMemberRole.developer)
+                }
                 return user.id in ids
             else:
                 self.owner_id = owner_id = app.owner.id
@@ -1479,6 +1495,20 @@ class Bot(BotBase, discord.Client):
         The type of application command tree to use. Defaults to :class:`~discord.app_commands.CommandTree`.
 
         .. versionadded:: 2.0
+    allowed_contexts: :class:`~discord.app_commands.AppCommandContext`
+        The default allowed contexts that applies to all application commands
+        in the application command tree.
+
+        Note that you can override this on a per command basis.
+
+        .. versionadded:: 2.4
+    allowed_installs: :class:`~discord.app_commands.AppInstallationType`
+        The default allowed install locations that apply to all application commands
+        in the application command tree.
+
+        Note that you can override this on a per command basis.
+
+        .. versionadded:: 2.4
     """
 
     pass
