@@ -111,12 +111,17 @@ class SleepHandle:
         self.loop: asyncio.AbstractEventLoop = loop
         self.future: asyncio.Future[None] = loop.create_future()
         relative_delta = discord.utils.compute_timedelta(dt)
-        self.handle = loop.call_later(relative_delta, self.future.set_result, True)
+        self.handle = loop.call_later(relative_delta, self._wrapped_set_result, self.future)
+
+    @staticmethod
+    def _wrapped_set_result(future: asyncio.Future) -> None:
+        if not future.done():
+            future.set_result(None)
 
     def recalculate(self, dt: datetime.datetime) -> None:
         self.handle.cancel()
         relative_delta = discord.utils.compute_timedelta(dt)
-        self.handle: asyncio.TimerHandle = self.loop.call_later(relative_delta, self.future.set_result, True)
+        self.handle: asyncio.TimerHandle = self.loop.call_later(relative_delta, self._wrapped_set_result, self.future)
 
     def wait(self) -> asyncio.Future[Any]:
         return self.future
@@ -144,6 +149,7 @@ class Loop(Generic[LF]):
         time: Union[datetime.time, Sequence[datetime.time]],
         count: Optional[int],
         reconnect: bool,
+        name: Optional[str],
     ) -> None:
         self.coro: LF = coro
         self.reconnect: bool = reconnect
@@ -165,6 +171,7 @@ class Loop(Generic[LF]):
         self._is_being_cancelled = False
         self._has_failed = False
         self._stop_next_iteration = False
+        self._name: str = f'discord-ext-tasks: {coro.__qualname__}' if name is None else name
 
         if self.count is not None and self.count <= 0:
             raise ValueError('count must be greater than 0 or None.')
@@ -282,6 +289,7 @@ class Loop(Generic[LF]):
             time=self._time,
             count=self.count,
             reconnect=self.reconnect,
+            name=self._name,
         )
         copy._injected = obj
         copy._before_loop = self._before_loop
@@ -395,7 +403,7 @@ class Loop(Generic[LF]):
             args = (self._injected, *args)
 
         self._has_failed = False
-        self._task = asyncio.create_task(self._loop(*args, **kwargs))
+        self._task = asyncio.create_task(self._loop(*args, **kwargs), name=self._name)
         return self._task
 
     def stop(self) -> None:
@@ -770,6 +778,7 @@ def loop(
     time: Union[datetime.time, Sequence[datetime.time]] = MISSING,
     count: Optional[int] = None,
     reconnect: bool = True,
+    name: Optional[str] = None,
 ) -> Callable[[LF], Loop[LF]]:
     """A decorator that schedules a task in the background for you with
     optional reconnect logic. The decorator returns a :class:`Loop`.
@@ -802,6 +811,12 @@ def loop(
         Whether to handle errors and restart the task
         using an exponential back-off algorithm similar to the
         one used in :meth:`discord.Client.connect`.
+    name: Optional[:class:`str`]
+        The name to assign to the internal task. By default
+        it is assigned a name based off of the callable name
+        such as ``discord-ext-tasks: function_name``.
+
+        .. versionadded:: 2.4
 
     Raises
     --------
@@ -821,6 +836,7 @@ def loop(
             count=count,
             time=time,
             reconnect=reconnect,
+            name=name,
         )
 
     return decorator
